@@ -1,12 +1,12 @@
 package MaxMind::DB::Writer::Tree::Processor::VisualizeTree;
-$MaxMind::DB::Writer::Tree::Processor::VisualizeTree::VERSION = '0.050006';
+$MaxMind::DB::Writer::Tree::Processor::VisualizeTree::VERSION = '0.050007';
 use strict;
 use warnings;
 
 use Data::Dumper::Concise;
 use Digest::MD5 qw( md5_hex );
 use GraphViz2;
-use Net::Works::Network 0.16;
+use Net::Works::Network;
 
 use Moose;
 
